@@ -53,6 +53,13 @@ Plotters
    CategoricalMarkovChainPlotter
 """
 
+############################################################################
+# A STUPID WORKAROUND FOR A MATPLOTLIB 1.4.0 BUG RELATED TO INTERACTIVE MODE
+# See: https://github.com/matplotlib/matplotlib/issues/3505
+import sys
+sys.ps1 = 'SOMETHING'
+#############################################################################
+
 import os, sys
 import tempfile
 
@@ -483,14 +490,16 @@ def gaussian_hinton(X, rows=None, cols=None, scale=1):
     for i in reversed(range(len(shape))):
         if shape[i] == 1 and i != rows and i != cols:
             squeezed_shape.pop(i)
-        if i < cols:
-            cols -= 1
-        if i < rows:
-            rows -= 1
+            if i < cols:
+                cols -= 1
+            if i < rows:
+                rows -= 1
     x = np.reshape(x, squeezed_shape)
     std = np.reshape(std, squeezed_shape)
 
     # Make explicit four axes
+    cols = cols + (4 - np.ndim(x))
+    rows = rows + (4 - np.ndim(x))
     x = misc.atleast_nd(x, 4)
     std = misc.atleast_nd(std, 4)
 
@@ -525,9 +534,9 @@ def gaussian_hinton(X, rows=None, cols=None, scale=1):
 
             #plt.subplot(M, N, i*N+j+1, sharey=ax[0], sharex=ax[0])
             if scale == 0:
-                return _hinton(x[i,j], vmax=vmax)
+                _hinton(x[i,j], vmax=vmax)
             else:
-                return _hinton(x[i,j], vmax=vmax, error=scale*std[i,j])
+                _hinton(x[i,j], vmax=vmax, error=scale*std[i,j])
             #matrix(x[i,j])
 
 
